@@ -15,7 +15,7 @@ QMainWindow(parent),
     if (!QSettings().contains("profilechangerwidget/height"))
         QSettings().setValue("profilechangerwidget/height", 48);
 
-    connect(ui->switchButton, SIGNAL(clicked()), this, SLOT(changeProfile()));
+    connect(ui->switchButton, SIGNAL(clicked()), this, SLOT(onChangeProfileClicked()));
     this->reloadSettings();
 }
 
