@@ -2,6 +2,7 @@
 #define _PROFILECHANGERWIDGET_H_
 
 #include <QMainWindow>
+#include <QDBusInterface>
 #include <qmaemo5homescreenadaptor.h>
 #include <QErrorMessage>
 #include "settingsdialog.h"
@@ -29,6 +30,8 @@ private:
     Ui::ProfileChangerWidget *ui;
 
 private:
+    QString getProfileName();
+    void setProfile(QString profileName);
     void switchProfile();
     void showIconSilent();
     void showIconGeneral();
